@@ -1,6 +1,6 @@
 package Catmandu::Exporter::XML;
-#ABSTRACT: serialize and export XML documents
-our $VERSION = '0.14'; #VERSION
+
+our $VERSION = '0.15';
 
 use Catmandu::Sane;
 use Moo;
@@ -68,23 +68,13 @@ sub add {
     }
 }
 
-
 1;
-
 __END__
 
-=pod
-
-=encoding UTF-8
-
 =head1 NAME
 
 Catmandu::Exporter::XML - serialize and export XML documents
 
-=head1 VERSION
-
-version 0.14
-
 =head1 DESCRIPTION
 
 This L<Catmandu::Exporter> exports items serialized as XML. Serialization is
@@ -127,15 +117,4 @@ The file extension C<.xml> is appended unless given.
 
 =back
 
-=head1 AUTHOR
-
-Jakob Voß
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2014 by Jakob Voß.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
