@@ -1,6 +1,6 @@
 package Catmandu::Fix::xml_read;
-#ABSTRACT: parse XML to MicroXML
-our $VERSION = '0.14'; #VERSION
+
+our $VERSION = '0.15';
 
 use Catmandu::Sane;
 use Moo;
@@ -59,25 +59,15 @@ sub emit {
     });
 }
 
-
 1;
-
 __END__
 
-=pod
-
-=encoding UTF-8
-
 =head1 NAME
 
-Catmandu::Fix::xml_read - parse XML to MicroXML
-
-=head1 VERSION
-
-version 0.14
+Catmandu::Fix::xml_read - parser XML to MicroXML
 
 =head1 SYNOPSIS
-
+     
   # parse XML string given in field 'xml' 
   xml_read(xml)
   xml_read(xml, attributes: 0)
@@ -135,15 +125,4 @@ not supported yet.
 L<Catmandu::Fix::xml_write>,
 L<Catmandu::Fix::xml_simple>
 
-=head1 AUTHOR
-
-Jakob Voß
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2014 by Jakob Voß.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
