@@ -1,6 +1,6 @@
 package Catmandu::Importer::XML;
-# ABSTRACT: Import serialized XML documents
-our $VERSION = '0.14'; # VERSION
+
+our $VERSION = '0.15';
 
 use namespace::clean;
 use Catmandu::Sane;
@@ -50,23 +50,13 @@ sub generator {
     }
 }
 
-
 1;
-
 __END__
 
-=pod
-
-=encoding UTF-8
-
 =head1 NAME
 
 Catmandu::Importer::XML - Import serialized XML documents
 
-=head1 VERSION
-
-version 0.14
-
 =head1 DESCRIPTION
 
 This L<Catmandu::Importer> reads XML and transforms it into a data structure. 
@@ -93,7 +83,7 @@ a key-value structure. For instance this document:
         <doz>baz</doz>
       </bar>
     </doc>
-
+     
 is imported as
 
     {
@@ -161,15 +151,6 @@ This module is just a thin layer on top of L<XML::Struct::Reader>. Have a look
 at L<XML::Struct> to implement Importers and Exporters for more specific
 XML-based data formats.
 
-=head1 AUTHOR
-
-Jakob Voß
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2014 by Jakob Voß.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
+
+=encoding utf8
